# ThreeDSecureData


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cavv** | **str** | The cardholder authentication value or AAV. | 
**eci** | **str** | The electronic commerce indicator for the 3DS transaction. | 
**version** | **str** | The version of 3-D Secure that was used. | 
**directory_response** | **str** | For 3-D Secure version 1, the enrolment response. For 3-D Secure version , the transaction status from the &#x60;ARes&#x60;. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


